#
# QuickLinks Zope Management interface enhancement.
# Peter Bengtsson, <mail@peterbe.com>
# 2002, ZPL license
#
#

from Globals import DTMLFile, InitializeClass
from OFS.SimpleItem import Item
from Acquisition import Implicit
from Persistence import Persistent

import meta_type_icons

class QuickLinks(Item, Implicit, Persistent):
    """ """
    id = 'QuickLinks'
    title = meta_type = 'Quick Links'
    manage_options = ({'label': 'Configure', 'action':'configureQuickLinksForm'},)

    configureQuickLinksForm = DTMLFile('dtml/configureForm', globals())

    def configureQuickLinks(self, meta_types=[], REQUEST=None):
        """ """
        root = self.restrictedTraverse("/")
        if hasattr(root, 'ql_meta_types'):
            root.manage_changeProperties({'ql_meta_types':meta_types})
        else:
            root.manage_addProperty('ql_meta_types', meta_types, 'lines')

        if REQUEST is not None:
            return self.configureQuickLinksForm(self, REQUEST)

    def make_ql_property(self):
        """ """
        root = self.restrictedTraverse("/")
        if not hasattr(root, 'ql_meta_types'):
            root.manage_addProperty('ql_meta_types', [], 'lines')

    def getAllMetaTypes(self):
        """ """
        return self.filtered_meta_types()

    def addMetaTypes(self, all_meta_types=[], REQUEST=None):
        """ """
        ql_meta_types = self.ql_meta_types
        for meta_type in all_meta_types:
            if meta_type not in ql_meta_types:
                ql_meta_types.append(meta_type)
        root = self.restrictedTraverse("/")
        root.manage_changeProperties({'ql_meta_types':ql_meta_types})

        if REQUEST is not None:
            return self.configureQuickLinksForm(self, REQUEST)

    def removeMetaTypes(self, ql_meta_types=[], REQUEST=None):
        """ """
        new_ql_meta_types= []
        for meta_type in self.ql_meta_types:
            if meta_type not in ql_meta_types:
                new_ql_meta_types.append(meta_type)

        root = self.restrictedTraverse("/")
        root.manage_changeProperties({'ql_meta_types':new_ql_meta_types})

        if REQUEST is not None:
            return self.configureQuickLinksForm(self, REQUEST)

    def showQuickLinks(self, all_meta_types=None):
        """ """
        self.make_ql_property()
        if all_meta_types is None:
            all_meta_types = self.getAllMetaTypes()
        paths = {}
        for meta_type in all_meta_types:
            paths[meta_type['name']] = meta_type['action']

        s = ''
        icons_dict = meta_type_icons.dict
        for meta_type in self.ql_meta_types:
            if paths.has_key(meta_type):
                if icons_dict.has_key(meta_type):
                    mod_meta_type = '<img src="/%s" alt="%s" border="0" />'%\
                                    (icons_dict[meta_type], meta_type)
                else:
                    mod_meta_type=meta_type
                s = """%s
                <a href="%s" title="%s"
                style="font-size:10px;text-decoration:underline;">%s</a>
                &nbsp;&nbsp;"""%(s,
                                 paths[meta_type],
                                 meta_type,
                                 mod_meta_type
                                 )
        return s


InitializeClass(QuickLinks)
